@@ -5,7 +5,7 @@
 // Implementation of Blob
 //
 
-#define MAGICK_IMPLEMENTATION
+#define MAGICKCORE_IMPLEMENTATION  1
 
 #include "Magick++/Include.h"
 #include "Magick++/Thread.h"
