@@ -244,7 +244,7 @@ Magick::Color::operator std::string() const
 }
 
 // Set color via ImageMagick PixelPacket
-const Magick::Color& Magick::Color::operator= ( const MagickLib::PixelPacket &color_ )
+const Magick::Color& Magick::Color::operator= ( const MagickCore::PixelPacket &color_ )
 {
   *_pixel = color_;
   if ( color_.opacity != OpaqueOpacity )
