@@ -93,7 +93,7 @@ Magick::Drawable& Magick::Drawable::operator= (const Magick::Drawable& original_
 }
 
 // Operator to invoke contained object
-void Magick::Drawable::operator()( MagickLib::DrawingWand * context_ ) const
+void Magick::Drawable::operator()( MagickCore::DrawingWand * context_ ) const
 {
   if(dp)
     dp->operator()( context_ );
@@ -173,7 +173,7 @@ Magick::VPath& Magick::VPath::operator= (const Magick::VPath& original_ )
 }
 
 // Operator to invoke contained object
-void Magick::VPath::operator()( MagickLib::DrawingWand * context_ ) const
+void Magick::VPath::operator()( MagickCore::DrawingWand * context_ ) const
 {
   if(dp)
     dp->operator()( context_ );
@@ -233,7 +233,7 @@ Magick::DrawableAffine::DrawableAffine( void )
 Magick::DrawableAffine::~DrawableAffine( void )
 {
 }
-void Magick::DrawableAffine::operator()( MagickLib::DrawingWand * context_ ) const
+void Magick::DrawableAffine::operator()( MagickCore::DrawingWand * context_ ) const
 {
   DrawAffine( context_, &_affine );
 }
@@ -246,7 +246,7 @@ Magick::DrawableBase* Magick::DrawableAffine::copy() const
 Magick::DrawableArc::~DrawableArc( void )
 {
 }
-void Magick::DrawableArc::operator()( MagickLib::DrawingWand * context_ ) const
+void Magick::DrawableArc::operator()( MagickCore::DrawingWand * context_ ) const
 {
   DrawArc( context_, _startX, _startY, _endX, _endY, _startDegrees, _endDegrees );
 }
@@ -273,7 +273,7 @@ Magick::DrawableBezier::DrawableBezier( const Magick::DrawableBezier& original_
 Magick::DrawableBezier::~DrawableBezier( void )
 {
 }
-void Magick::DrawableBezier::operator()( MagickLib::DrawingWand * context_ ) const
+void Magick::DrawableBezier::operator()( MagickCore::DrawingWand * context_ ) const
 {
   unsigned long num_coords = (unsigned long) _coordinates.size();
   PointInfo *coordinates = new PointInfo[num_coords];
@@ -305,7 +305,7 @@ Magick::DrawableBase* Magick::DrawableBezier::copy() const
 Magick::DrawablePopClipPath::~DrawablePopClipPath ( void )
 {
 }
-void Magick::DrawablePopClipPath::operator() ( MagickLib::DrawingWand * context_ ) const
+void Magick::DrawablePopClipPath::operator() ( MagickCore::DrawingWand * context_ ) const
 {
   DrawPopClipPath( context_ );
   DrawPopDefs(context_);
@@ -330,7 +330,7 @@ Magick::DrawablePushClipPath::~DrawablePushClipPath( void )
 {
 }
 void Magick::DrawablePushClipPath::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawPushDefs(context_);
   DrawPushClipPath( context_, _id.c_str());
@@ -355,7 +355,7 @@ Magick::DrawableClipPath::DrawableClipPath ( const Magick::DrawableClipPath& ori
 Magick::DrawableClipPath::~DrawableClipPath( void )
 {
 }
-void Magick::DrawableClipPath::operator()( MagickLib::DrawingWand * context_ ) const
+void Magick::DrawableClipPath::operator()( MagickCore::DrawingWand * context_ ) const
 {
 	(void) DrawSetClipPath( context_, _id.c_str());
 }
@@ -368,7 +368,7 @@ Magick::DrawableBase* Magick::DrawableClipPath::copy() const
 Magick::DrawableCircle::~DrawableCircle ( void )
 {
 }
-void Magick::DrawableCircle::operator()( MagickLib::DrawingWand * context_ ) const
+void Magick::DrawableCircle::operator()( MagickCore::DrawingWand * context_ ) const
 {
   DrawCircle( context_, _originX, _originY, _perimX, _perimY );
 }
@@ -381,7 +381,7 @@ Magick::DrawableBase* Magick::DrawableCircle::copy() const
 Magick::DrawableColor::~DrawableColor( void )
 {
 }
-void Magick::DrawableColor::operator()( MagickLib::DrawingWand * context_ ) const
+void Magick::DrawableColor::operator()( MagickCore::DrawingWand * context_ ) const
 {
   DrawColor( context_, _x, _y, _paintMethod );
 }
@@ -534,7 +534,7 @@ std::string Magick::DrawableCompositeImage::magick( void )
 }
 
 void Magick::DrawableCompositeImage::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   MagickWand
     *magick_wand;
@@ -555,7 +555,7 @@ Magick::DrawableEllipse::~DrawableEllipse( void )
 {
 }
 void Magick::DrawableEllipse::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawEllipse( context_, _originX, _originY, _radiusX, _radiusY,
                _arcStart, _arcEnd );
@@ -580,7 +580,7 @@ Magick::DrawableFillColor::~DrawableFillColor( void )
 {
 }
 void Magick::DrawableFillColor::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   PixelPacket color = static_cast<PixelPacket>(_color);
   PixelWand *pixel_wand=NewPixelWand();
@@ -598,7 +598,7 @@ Magick::DrawableFillRule::~DrawableFillRule ( void )
 {
 }
 void Magick::DrawableFillRule::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawSetFillRule( context_, _fillRule );
 }
@@ -612,7 +612,7 @@ Magick::DrawableFillOpacity::~DrawableFillOpacity ( void )
 {
 }
 void Magick::DrawableFillOpacity::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawSetFillOpacity( context_, _opacity );
 }
@@ -653,7 +653,7 @@ Magick::DrawableFont::DrawableFont ( const Magick::DrawableFont& original_ )
 Magick::DrawableFont::~DrawableFont ( void )
 {
 }
-void Magick::DrawableFont::operator()( MagickLib::DrawingWand * context_ ) const
+void Magick::DrawableFont::operator()( MagickCore::DrawingWand * context_ ) const
 {
   // font
   if(_font.length())
@@ -686,7 +686,7 @@ Magick::DrawableGravity::~DrawableGravity ( void )
 {
 }
 void Magick::DrawableGravity::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawSetGravity( context_, _gravity );
 }
@@ -699,7 +699,7 @@ Magick::DrawableBase* Magick::DrawableGravity::copy() const
 Magick::DrawableLine::~DrawableLine ( void )
 {
 }
-void Magick::DrawableLine::operator()( MagickLib::DrawingWand * context_ ) const
+void Magick::DrawableLine::operator()( MagickCore::DrawingWand * context_ ) const
 {
   DrawLine( context_, _startX, _startY, _endX, _endY );
 }
@@ -712,7 +712,7 @@ Magick::DrawableBase* Magick::DrawableLine::copy() const
 Magick::DrawableMatte::~DrawableMatte ( void )
 {
 }
-void Magick::DrawableMatte::operator()( MagickLib::DrawingWand * context_ ) const
+void Magick::DrawableMatte::operator()( MagickCore::DrawingWand * context_ ) const
 {
   DrawMatte( context_, _x, _y, _paintMethod );
 }
@@ -734,7 +734,7 @@ Magick::DrawablePath::DrawablePath ( const Magick::DrawablePath& original_ )
 Magick::DrawablePath::~DrawablePath ( void )
 {
 }
-void Magick::DrawablePath::operator()( MagickLib::DrawingWand * context_ ) const
+void Magick::DrawablePath::operator()( MagickCore::DrawingWand * context_ ) const
 {
   DrawPathStart( context_ );
 
@@ -753,7 +753,7 @@ Magick::DrawableBase* Magick::DrawablePath::copy() const
 Magick::DrawablePoint::~DrawablePoint ( void )
 {
 }
-void Magick::DrawablePoint::operator()( MagickLib::DrawingWand * context_ ) const
+void Magick::DrawablePoint::operator()( MagickCore::DrawingWand * context_ ) const
 {
   DrawPoint( context_, _x, _y );
 }
@@ -767,7 +767,7 @@ Magick::DrawablePointSize::~DrawablePointSize ( void )
 {
 }
 void Magick::DrawablePointSize::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawSetFontSize( context_, _pointSize );
 }
@@ -791,7 +791,7 @@ Magick::DrawablePolygon::~DrawablePolygon ( void )
 {
 }
 void Magick::DrawablePolygon::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   unsigned long num_coords = (unsigned long) _coordinates.size();
   PointInfo *coordinates = new PointInfo[num_coords];
@@ -831,7 +831,7 @@ Magick::DrawablePolyline::~DrawablePolyline ( void )
 {
 }
 void Magick::DrawablePolyline::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   unsigned long num_coords = (unsigned long) _coordinates.size();
   PointInfo *coordinates = new PointInfo[num_coords];
@@ -860,7 +860,7 @@ Magick::DrawablePopGraphicContext::~DrawablePopGraphicContext ( void )
 {
 }
 void Magick::DrawablePopGraphicContext::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   PopDrawingWand( context_ );
 }
@@ -874,7 +874,7 @@ Magick::DrawablePushGraphicContext::~DrawablePushGraphicContext ( void )
 {
 }
 void Magick::DrawablePushGraphicContext::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   PushDrawingWand( context_ );
 }
@@ -888,7 +888,7 @@ Magick::DrawablePopPattern::~DrawablePopPattern ( void )
 {
 }
 void Magick::DrawablePopPattern::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   (void) DrawPopPattern( context_ );
 }
@@ -922,7 +922,7 @@ Magick::DrawablePushPattern::~DrawablePushPattern ( void )
 {
 }
 void Magick::DrawablePushPattern::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   (void) DrawPushPattern( context_, _id.c_str(), _x, _y, _width, _height );
 }
@@ -936,7 +936,7 @@ Magick::DrawableRectangle::~DrawableRectangle ( void )
 {
 }
 void Magick::DrawableRectangle::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawRectangle( context_, _upperLeftX, _upperLeftY,
                  _lowerRightX, _lowerRightY );
@@ -951,7 +951,7 @@ Magick::DrawableRotation::~DrawableRotation ( void )
 {
 }
 void Magick::DrawableRotation::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawRotate( context_, _angle );
 }
@@ -965,7 +965,7 @@ Magick::DrawableRoundRectangle::~DrawableRoundRectangle ( void )
 {
 }
 void Magick::DrawableRoundRectangle::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawRoundRectangle( context_, _centerX,_centerY, _width,_hight,
                       _cornerWidth, _cornerHeight);
@@ -980,7 +980,7 @@ Magick::DrawableScaling::~DrawableScaling ( void )
 {
 }
 void Magick::DrawableScaling::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawScale( context_, _x, _y );
 }
@@ -994,7 +994,7 @@ Magick::DrawableSkewX::~DrawableSkewX ( void )
 {
 }
 void Magick::DrawableSkewX::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawSkewX( context_, _angle );
 }
@@ -1007,7 +1007,7 @@ Magick::DrawableBase* Magick::DrawableSkewX::copy() const
 Magick::DrawableSkewY::~DrawableSkewY ( void )
 {
 }
-void Magick::DrawableSkewY::operator()( MagickLib::DrawingWand * context_ ) const
+void Magick::DrawableSkewY::operator()( MagickCore::DrawingWand * context_ ) const
 {
   DrawSkewY( context_, _angle );
 }
@@ -1055,7 +1055,7 @@ Magick::DrawableDashArray& Magick::DrawableDashArray::operator=
   return *this;
 }
 void Magick::DrawableDashArray::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   (void) DrawSetStrokeDashArray( context_, _size, _dasharray );
 }
@@ -1125,7 +1125,7 @@ Magick::DrawableDashOffset::~DrawableDashOffset ( void )
 {
 }
 void Magick::DrawableDashOffset::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawSetStrokeDashOffset( context_, _offset );
 }
@@ -1139,7 +1139,7 @@ Magick::DrawableStrokeLineCap::~DrawableStrokeLineCap ( void )
 {
 }
 void Magick::DrawableStrokeLineCap::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawSetStrokeLineCap( context_, _linecap );
 }
@@ -1153,7 +1153,7 @@ Magick::DrawableStrokeLineJoin::~DrawableStrokeLineJoin ( void )
 {
 }
 void Magick::DrawableStrokeLineJoin::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawSetStrokeLineJoin( context_, _linejoin );
 }
@@ -1167,7 +1167,7 @@ Magick::DrawableMiterLimit::~DrawableMiterLimit ( void )
 {
 }
 void Magick::DrawableMiterLimit::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawSetStrokeMiterLimit( context_, _miterlimit );
 }
@@ -1181,7 +1181,7 @@ Magick::DrawableStrokeAntialias::~DrawableStrokeAntialias ( void )
 {
 }
 void Magick::DrawableStrokeAntialias::operator()
-( MagickLib::DrawingWand * context_ ) const
+( MagickCore::DrawingWand * context_ ) const
 {
   DrawSetStrokeAntialias( context_, static_cast<MagickBooleanType>
     (_flag ? MagickTrue : MagickFalse) );
@@ -1207,7 +1207,7 @@ Magick::DrawableStrokeColor::~DrawableStrokeColor ( void )
 {
 }
 void Magick::DrawableStrokeColor::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   PixelPacket color = static_cast<PixelPacket>(_color);
   PixelWand *pixel_wand=NewPixelWand();
@@ -1225,7 +1225,7 @@ Magick::DrawableStrokeOpacity::~DrawableStrokeOpacity ( void )
 {
 }
 void Magick::DrawableStrokeOpacity::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawSetStrokeOpacity( context_, _opacity );
 }
@@ -1239,7 +1239,7 @@ Magick::DrawableStrokeWidth::~DrawableStrokeWidth ( void )
 {
 }
 void Magick::DrawableStrokeWidth::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawSetStrokeWidth( context_, _width );
 }
@@ -1277,7 +1277,7 @@ Magick::DrawableText::~DrawableText ( void )
 {
 }
 void Magick::DrawableText::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawSetTextEncoding( context_, _encoding.c_str() );
   DrawAnnotation( context_, _x, _y,
@@ -1302,7 +1302,7 @@ Magick::DrawableTextAntialias::~DrawableTextAntialias ( void )
 {
 }
 void Magick::DrawableTextAntialias::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawSetTextAntialias( context_, static_cast<MagickBooleanType>
     (_flag ? MagickTrue : MagickFalse) );
@@ -1328,7 +1328,7 @@ Magick::DrawableTextDecoration::~DrawableTextDecoration( void )
 {
 }
 void Magick::DrawableTextDecoration::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawSetTextDecoration( context_, _decoration );
 }
@@ -1353,7 +1353,7 @@ Magick::DrawableTextUnderColor::~DrawableTextUnderColor ( void )
 {
 }
 void Magick::DrawableTextUnderColor::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   PixelPacket color = static_cast<PixelPacket>(_color);
   PixelWand *pixel_wand=NewPixelWand();
@@ -1371,7 +1371,7 @@ Magick::DrawableTranslation::~DrawableTranslation ( void )
 {
 }
 void Magick::DrawableTranslation::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawTranslate( context_, _x, _y );
 }
@@ -1385,7 +1385,7 @@ Magick::DrawableViewbox::~DrawableViewbox ( void )
 {
 }
 void Magick::DrawableViewbox::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawSetViewbox( context_, _x1, _y1, _x2, _y2 );
 }
@@ -1488,7 +1488,7 @@ Magick::PathArcAbs::PathArcAbs ( const Magick::PathArcAbs& original_ )
 Magick::PathArcAbs::~PathArcAbs ( void )
 {
 }
-void Magick::PathArcAbs::operator()( MagickLib::DrawingWand * context_ ) const
+void Magick::PathArcAbs::operator()( MagickCore::DrawingWand * context_ ) const
 {
   for( PathArcArgsList::const_iterator p = _coordinates.begin();
        p != _coordinates.end(); p++ )
@@ -1519,7 +1519,7 @@ Magick::PathArcRel::PathArcRel ( const Magick::PathArcRel& original_ )
 Magick::PathArcRel::~PathArcRel ( void )
 {
 }
-void Magick::PathArcRel::operator()( MagickLib::DrawingWand * context_ ) const
+void Magick::PathArcRel::operator()( MagickCore::DrawingWand * context_ ) const
 {
   for( PathArcArgsList::const_iterator p = _coordinates.begin();
        p != _coordinates.end(); p++ )
@@ -1540,7 +1540,7 @@ Magick::VPathBase* Magick::PathArcRel::copy() const
 Magick::PathClosePath::~PathClosePath ( void )
 {
 }
-void Magick::PathClosePath::operator()( MagickLib::DrawingWand * context_ ) const
+void Magick::PathClosePath::operator()( MagickCore::DrawingWand * context_ ) const
 {
   DrawPathClose( context_ );
 }
@@ -1637,7 +1637,7 @@ Magick::PathCurvetoAbs::~PathCurvetoAbs ( void )
 {
 }
 void Magick::PathCurvetoAbs::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   for( PathCurveToArgsList::const_iterator p = _args.begin();
        p != _args.end(); p++ )
@@ -1668,7 +1668,7 @@ Magick::PathCurvetoRel::~PathCurvetoRel ( void )
 {
 }
 void Magick::PathCurvetoRel::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   for( PathCurveToArgsList::const_iterator p = _args.begin();
        p != _args.end(); p++ )
@@ -1701,7 +1701,7 @@ Magick::PathSmoothCurvetoAbs::~PathSmoothCurvetoAbs ( void )
 {
 }
 void Magick::PathSmoothCurvetoAbs::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   for( CoordinateList::const_iterator p = _coordinates.begin();
        p != _coordinates.end(); p++ )
@@ -1737,7 +1737,7 @@ Magick::PathSmoothCurvetoRel::~PathSmoothCurvetoRel ( void )
 {
 }
 void Magick::PathSmoothCurvetoRel::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   for( CoordinateList::const_iterator p = _coordinates.begin();
        p != _coordinates.end(); p++ )
@@ -1845,7 +1845,7 @@ Magick::PathQuadraticCurvetoAbs::~PathQuadraticCurvetoAbs ( void )
 {
 }
 void Magick::PathQuadraticCurvetoAbs::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   for( PathQuadraticCurvetoArgsList::const_iterator p = _args.begin();
        p != _args.end(); p++ )
@@ -1878,7 +1878,7 @@ Magick::PathQuadraticCurvetoRel::~PathQuadraticCurvetoRel ( void )
 {
 }
 void Magick::PathQuadraticCurvetoRel::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   for( PathQuadraticCurvetoArgsList::const_iterator p = _args.begin();
        p != _args.end(); p++ )
@@ -1911,7 +1911,7 @@ Magick::PathSmoothQuadraticCurvetoAbs::~PathSmoothQuadraticCurvetoAbs ( void )
 {
 }
 void Magick::PathSmoothQuadraticCurvetoAbs::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   for( CoordinateList::const_iterator p = _coordinates.begin();
        p != _coordinates.end(); p++ )
@@ -1943,7 +1943,7 @@ Magick::PathSmoothQuadraticCurvetoRel::~PathSmoothQuadraticCurvetoRel ( void )
 {
 }
 void Magick::PathSmoothQuadraticCurvetoRel::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   for( CoordinateList::const_iterator p = _coordinates.begin();
        p != _coordinates.end(); p++ )
@@ -1975,7 +1975,7 @@ Magick::PathLinetoAbs::PathLinetoAbs ( const Magick::PathLinetoAbs& original_ )
 Magick::PathLinetoAbs::~PathLinetoAbs ( void )
 {
 }
-void Magick::PathLinetoAbs::operator()( MagickLib::DrawingWand * context_ ) const
+void Magick::PathLinetoAbs::operator()( MagickCore::DrawingWand * context_ ) const
 {
   for( CoordinateList::const_iterator p = _coordinates.begin();
        p != _coordinates.end(); p++ )
@@ -2003,7 +2003,7 @@ Magick::PathLinetoRel::PathLinetoRel ( const Magick::PathLinetoRel& original_ )
 Magick::PathLinetoRel::~PathLinetoRel ( void )
 {
 }
-void Magick::PathLinetoRel::operator()( MagickLib::DrawingWand * context_ ) const
+void Magick::PathLinetoRel::operator()( MagickCore::DrawingWand * context_ ) const
 {
   for( CoordinateList::const_iterator p = _coordinates.begin();
        p != _coordinates.end(); p++ )
@@ -2024,7 +2024,7 @@ Magick::PathLinetoHorizontalAbs::~PathLinetoHorizontalAbs ( void )
 {
 }
 void Magick::PathLinetoHorizontalAbs::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawPathLineToHorizontalAbsolute( context_, _x );
 }
@@ -2036,7 +2036,7 @@ Magick::PathLinetoHorizontalRel::~PathLinetoHorizontalRel ( void )
 {
 }
 void Magick::PathLinetoHorizontalRel::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawPathLineToHorizontalRelative( context_, _x );
 }
@@ -2052,7 +2052,7 @@ Magick::PathLinetoVerticalAbs::~PathLinetoVerticalAbs ( void )
 {
 }
 void Magick::PathLinetoVerticalAbs::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawPathLineToVerticalAbsolute( context_, _y );
 }
@@ -2064,7 +2064,7 @@ Magick::PathLinetoVerticalRel::~PathLinetoVerticalRel ( void )
 {
 }
 void Magick::PathLinetoVerticalRel::operator()
-  ( MagickLib::DrawingWand * context_ ) const
+  ( MagickCore::DrawingWand * context_ ) const
 {
   DrawPathLineToVerticalRelative( context_, _y );
 }
@@ -2093,7 +2093,7 @@ Magick::PathMovetoAbs::PathMovetoAbs ( const Magick::PathMovetoAbs& original_ )
 Magick::PathMovetoAbs::~PathMovetoAbs ( void )
 {
 }
-void Magick::PathMovetoAbs::operator()( MagickLib::DrawingWand * context_ ) const
+void Magick::PathMovetoAbs::operator()( MagickCore::DrawingWand * context_ ) const
 {
   for( CoordinateList::const_iterator p = _coordinates.begin();
        p != _coordinates.end(); p++ )
@@ -2121,7 +2121,7 @@ Magick::PathMovetoRel::PathMovetoRel ( const Magick::PathMovetoRel& original_ )
 Magick::PathMovetoRel::~PathMovetoRel ( void )
 {
 }
-void Magick::PathMovetoRel::operator()( MagickLib::DrawingWand * context_ ) const
+void Magick::PathMovetoRel::operator()( MagickCore::DrawingWand * context_ ) const
 {
   for( CoordinateList::const_iterator p = _coordinates.begin();
        p != _coordinates.end(); p++ )
