@@ -292,9 +292,8 @@ MagickDLLDecl void Magick::throwException( ExceptionInfo &exception_ )
   if ( exception_.description != 0 )
     message += " (" + std::string(exception_.description) + ")";
 
-
   ExceptionType severity = exception_.severity;
-  ClearMagickException( &exception_ );
+  DestroyExceptionInfo( &exception_ );
 
   switch ( severity )
     {
