@@ -331,7 +331,7 @@ Magick::Geometry::operator std::string() const
 }
 
 // Construct from RectangleInfo
-Magick::Geometry::Geometry ( const MagickLib::RectangleInfo &rectangle_ )
+Magick::Geometry::Geometry ( const MagickCore::RectangleInfo &rectangle_ )
   : _width(static_cast<unsigned int>(rectangle_.width)),
     _height(static_cast<unsigned int>(rectangle_.height)),
     _xOff(static_cast<unsigned int>(AbsoluteValue(rectangle_.x))),
@@ -347,7 +347,7 @@ Magick::Geometry::Geometry ( const MagickLib::RectangleInfo &rectangle_ )
 }
 
 // Return an ImageMagick RectangleInfo struct
-Magick::Geometry::operator MagickLib::RectangleInfo() const
+Magick::Geometry::operator MagickCore::RectangleInfo() const
 {
   RectangleInfo rectangle;
   rectangle.width = _width;
