@@ -123,6 +123,8 @@ namespace Magick
 
     // Add noise to image with specified noise type
     void            addNoise ( const NoiseType noiseType_ );
+    void            addNoiseChannel ( const ChannelType channel_,
+                                      const NoiseType noiseType_);
 
     // Transform image by specified affine (or free transform) matrix.
     void            affineTransform ( const DrawableAffine &affine );
@@ -167,6 +169,9 @@ namespace Magick
     // specifies the standard deviation of the Laplacian, in pixels.
     void            blur ( const double radius_ = 0.0,
                            const double sigma_ = 1.0  );
+    void            blurChannel ( const ChannelType channel_,
+                                  const double radius_ = 0.0,
+                                  const double sigma_ = 1.0  );
     
     // Border image (add border to image)
     void            border ( const Geometry &geometry_
@@ -252,7 +257,16 @@ namespace Magick
     
     // Display image on screen
     void            display ( void );
-    
+
+    // Distort image.  distorts an image using various distortion methods, by
+    // mapping color lookups of the source image to a new destination image
+    // usally of the same size as the source image, unless 'bestfit' is set to
+    // true.
+    void            distort ( const DistortImageMethod method,
+                              const unsigned long number_arguments,
+                              const double *arguments,
+                              unsigned int bestfit = 0 );
+
     // Draw on image using a single drawable
     void            draw ( const Drawable &drawable_ );
 
@@ -337,8 +351,12 @@ namespace Magick
     void            frame ( const Geometry &geometry_ = frameGeometryDefault );
     void            frame ( const unsigned int width_,
                             const unsigned int height_,
-          const int innerBevel_ = 6,
+                            const int innerBevel_ = 6,
                             const int outerBevel_ = 6 );
+
+    // Applies a mathematical expression to the image.
+    void            fx ( const std::string expression,
+                         const Magick::ChannelType channel );
     
     // Gamma correct image
     void            gamma ( const double gamma_ );
@@ -351,6 +369,9 @@ namespace Magick
     // mask is specified by 'width_'. The standard deviation of the
     // gaussian bell curve is specified by 'sigma_'.
     void            gaussianBlur ( const double width_, const double sigma_ );
+    void            gaussianBlurChannel ( const ChannelType channel_,
+                                          const double width_,
+                                          const double sigma_ );
     
     // Implode image (special effect)
     void            implode ( const double factor_ );
@@ -414,6 +435,16 @@ namespace Magick
              const double saturation_,
              const double hue_ );
     
+    // Motion blur image with specified blur factor
+    // The radius_ parameter specifies the radius of the Gaussian, in
+    // pixels, not counting the center pixel.  The sigma_ parameter
+    // specifies the standard deviation of the Laplacian, in pixels.
+    // The angle_ parameter specifies the angle the object appears
+    // to be comming from (zero degrees is from the right).
+    void            motionBlur ( const double radius_,
+                                 const double sigma_,
+                                 const double angle_ );
+    
     // Negate colors in image.  Set grayscale to only negate grayscale
     // values in image.
     void            negate ( const bool grayscale_ = false );
@@ -477,6 +508,20 @@ namespace Magick
     void            raise ( const Geometry &geometry_ = raiseGeometryDefault,
           const bool raisedFlag_ = false );
     
+    // Random threshold image.
+    //
+    // Changes the value of individual pixels based on the intensity
+    // of each pixel compared to a random threshold.  The result is a
+    // low-contrast, two color image.  The thresholds_ argument is a
+    // geometry containing LOWxHIGH thresholds.  If the string
+    // contains 2x2, 3x3, or 4x4, then an ordered dither of order 2,
+    // 3, or 4 will be performed instead.  If a channel_ argument is
+    // specified then only the specified channel is altered.  This is
+    // a very fast alternative to 'quantize' based dithering.
+    void            randomThreshold( const Geometry &thresholds_ );
+    void            randomThresholdChannel( const Geometry &thresholds_,
+                                            const ChannelType channel_ );
+    
     // Read single image frame into current object
     void            read ( const std::string &imageSpec_ );
 
@@ -559,6 +604,9 @@ namespace Magick
     // specifies the standard deviation of the Laplacian, in pixels.
     void            sharpen ( const double radius_ = 0.0,
                               const double sigma_ = 1.0 );
+    void            sharpenChannel ( const ChannelType channel_,
+                                     const double radius_ = 0.0,
+                                     const double sigma_ = 1.0 );
 
     // Shave pixels from image edges.
     void            shave ( const Geometry &geometry_ );
@@ -577,6 +625,14 @@ namespace Magick
     // Spread pixels randomly within image by specified ammount
     void            spread ( const unsigned int amount_ = 3 );
     
+    // Sparse color image, given a set of coordinates, interpolates the colors
+    // found at those coordinates, across the whole image, using various
+    // methods.
+    void            sparseColor ( const ChannelType channel,
+                              const SparseColorMethod method,
+                              const unsigned long number_arguments,
+                              const double *arguments );
+
     // Add a digital watermark to the image (based on second image)
     void            stegano ( const Image &watermark_ );
     
@@ -629,6 +685,11 @@ namespace Magick
                                   const double sigma_,
                                   const double amount_,
                                   const double threshold_ );
+    void            unsharpmaskChannel ( const ChannelType channel_,
+                                         const double radius_,
+                                         const double sigma_,
+                                         const double amount_,
+                                         const double threshold_ );
 
     // Map image pixels to a sine wave
     void            wave ( const double amplitude_ = 25.0,
@@ -1139,7 +1200,7 @@ typedef struct _ImageStatistics
     //    Bilevel        Grayscale       GrayscaleMatte
     //    Palette        PaletteMatte    TrueColor
     //    TrueColorMatte ColorSeparation ColorSeparationMatte
-    ImageType       type ( void ) const;
+    ImageType       type ( void );
 
     // Print detailed information about the image
     void            verbose ( const bool verboseFlag_ );
