@@ -220,6 +220,24 @@ namespace Magick
   using MagickCore::BackgroundDispose;
   using MagickCore::PreviousDispose;
 
+  // Distort methods
+  using MagickCore::DistortImageMethod;
+  using MagickCore::UndefinedDistortion;
+  using MagickCore::AffineDistortion;
+  using MagickCore::AffineProjectionDistortion;
+  using MagickCore::ScaleRotateTranslateDistortion;
+  using MagickCore::PerspectiveDistortion;
+  using MagickCore::PerspectiveProjectionDistortion;
+  using MagickCore::BilinearDistortion;
+  using MagickCore::PolynomialDistortion;
+  using MagickCore::ArcDistortion;
+  using MagickCore::PolarDistortion;
+  using MagickCore::DePolarDistortion;
+  using MagickCore::BarrelDistortion;
+  using MagickCore::BarrelInverseDistortion;
+  using MagickCore::ShepardsDistortion;
+  using MagickCore::SentinelDistortion;
+
   // Endian options
   using MagickCore::EndianType;
   using MagickCore::UndefinedEndian;
@@ -424,6 +442,15 @@ namespace Magick
   // IndexPacket type
   using MagickCore::IndexPacket;
 
+  // Sparse Color methods
+  using MagickCore::SparseColorMethod;
+  using MagickCore::UndefinedColorInterpolate;
+  using MagickCore::BarycentricColorInterpolate;
+  using MagickCore::BilinearColorInterpolate;
+  using MagickCore::PolynomialColorInterpolate;
+  using MagickCore::ShepardsColorInterpolate;
+  using MagickCore::VoronoiColorInterpolate;
+
   // StorageType type
   using MagickCore::StorageType;
   using MagickCore::CharPixel;
@@ -463,7 +490,9 @@ namespace Magick
   //
   // ImageMagick symbols used in implementation code
   //
+  using MagickCore::AcquireCacheView;
   using MagickCore::AcquireCacheViewPixels;
+  using MagickCore::AcquireImage;
   using MagickCore::AcquireImagePixels;
   using MagickCore::AcquireMagickMemory;
   using MagickCore::AcquireQuantumInfo;
@@ -472,9 +501,9 @@ namespace Magick
   using MagickCore::AdaptiveBlurImage;
   using MagickCore::AdaptiveThresholdImage;
   using MagickCore::AddNoiseImage;
+  using MagickCore::AddNoiseImageChannel;
   using MagickCore::AffineMatrix;
   using MagickCore::AffineTransformImage;
-  using MagickCore::AcquireImage;
   using MagickCore::AnnotateImage;
   using MagickCore::AspectValue;
   using MagickCore::Base64Decode;
@@ -485,6 +514,7 @@ namespace Magick
   using MagickCore::BlobToImage;
   using MagickCore::BlobWarning;
   using MagickCore::BlurImage;
+  using MagickCore::BlurImageChannel;
   using MagickCore::BorderImage;
   using MagickCore::CacheError;
   using MagickCore::CacheFatalError;
@@ -496,7 +526,6 @@ namespace Magick
   using MagickCore::CloneImage;
   using MagickCore::CloneImageInfo;
   using MagickCore::CloneQuantizeInfo;
-  using MagickCore::DestroyCacheView;
   using MagickCore::CoderError;
   using MagickCore::CoderFatalError;
   using MagickCore::CoderWarning;
@@ -508,6 +537,8 @@ namespace Magick
   using MagickCore::ConfigureWarning;
   using MagickCore::ConstituteImage;
   using MagickCore::ContrastImage;
+  using MagickCore::ConvertHSLToRGB;
+  using MagickCore::ConvertRGBToHSL;
   using MagickCore::ConvolveImage;
   using MagickCore::CopyMagickString;
   using MagickCore::CorruptImageError;
@@ -521,6 +552,7 @@ namespace Magick
   using MagickCore::DeleteImageOption;
   using MagickCore::DeleteImageRegistry;
   using MagickCore::DespeckleImage;
+  using MagickCore::DestroyCacheView;
   using MagickCore::DestroyDrawInfo;
   using MagickCore::DestroyDrawingWand;
   using MagickCore::DestroyExceptionInfo;
@@ -532,6 +564,7 @@ namespace Magick
   using MagickCore::DestroyQuantumInfo;
   using MagickCore::DestroyStringInfo;
   using MagickCore::DisplayImages;
+  using MagickCore::DistortImage;
   using MagickCore::DrawAffine;
   using MagickCore::DrawAllocateWand;
   using MagickCore::DrawAnnotation;
@@ -575,11 +608,9 @@ namespace Magick
   using MagickCore::DrawPolyline;
   using MagickCore::DrawPopClipPath;
   using MagickCore::DrawPopDefs;
-  using MagickCore::PopDrawingWand;
   using MagickCore::DrawPopPattern;
   using MagickCore::DrawPushClipPath;
   using MagickCore::DrawPushDefs;
-  using MagickCore::PushDrawingWand;
   using MagickCore::DrawPushPattern;
   using MagickCore::DrawRectangle;
   using MagickCore::DrawRender;
@@ -589,8 +620,8 @@ namespace Magick
   using MagickCore::DrawSetClipPath;
   using MagickCore::DrawSetClipRule;
   using MagickCore::DrawSetClipUnits;
-  using MagickCore::DrawSetFillOpacity;
   using MagickCore::DrawSetFillColor;
+  using MagickCore::DrawSetFillOpacity;
   using MagickCore::DrawSetFillPatternURL;
   using MagickCore::DrawSetFillRule;
   using MagickCore::DrawSetFont;
@@ -600,7 +631,6 @@ namespace Magick
   using MagickCore::DrawSetFontStyle;
   using MagickCore::DrawSetFontWeight;
   using MagickCore::DrawSetGravity;
-  using MagickCore::DrawSetStrokeOpacity;
   using MagickCore::DrawSetStrokeAntialias;
   using MagickCore::DrawSetStrokeColor;
   using MagickCore::DrawSetStrokeDashArray;
@@ -608,6 +638,7 @@ namespace Magick
   using MagickCore::DrawSetStrokeLineCap;
   using MagickCore::DrawSetStrokeLineJoin;
   using MagickCore::DrawSetStrokeMiterLimit;
+  using MagickCore::DrawSetStrokeOpacity;
   using MagickCore::DrawSetStrokePatternURL;
   using MagickCore::DrawSetStrokeWidth;
   using MagickCore::DrawSetTextAntialias;
@@ -633,32 +664,35 @@ namespace Magick
   using MagickCore::FileOpenFatalError;
   using MagickCore::FileOpenWarning;
   using MagickCore::FlipImage;
+  using MagickCore::FloodfillPaintImage;
   using MagickCore::FlopImage;
   using MagickCore::FormatMagickString;
   using MagickCore::FrameImage;
   using MagickCore::FrameInfo;
+  using MagickCore::FxImageChannel;
   using MagickCore::GammaImage;
   using MagickCore::GammaImage;
   using MagickCore::GaussianBlurImage;
+  using MagickCore::GaussianBlurImageChannel;
   using MagickCore::GetAffineMatrix;
   using MagickCore::GetBlobSize;
-  using MagickCore::GetCacheViewPixels;
   using MagickCore::GetCacheViewIndexes;
-  using MagickCore::GetImageChannelMean;
-  using MagickCore::GetImageChannelRange;
-  using MagickCore::GetImageClipMask;
+  using MagickCore::GetCacheViewPixels;
   using MagickCore::GetColorTuple;
   using MagickCore::GetDrawInfo;
   using MagickCore::GetExceptionInfo;
   using MagickCore::GetGeometry;
   using MagickCore::GetImageBoundingBox;
   using MagickCore::GetImageChannelDepth;
+  using MagickCore::GetImageChannelMean;
+  using MagickCore::GetImageChannelRange;
+  using MagickCore::GetImageClipMask;
   using MagickCore::GetImageDepth;
   using MagickCore::GetImageInfo;
   using MagickCore::GetImageOption;
   using MagickCore::GetImagePixels;
-  using MagickCore::GetImageProperty;
   using MagickCore::GetImageProfile;
+  using MagickCore::GetImageProperty;
   using MagickCore::GetImageQuantizeError;
   using MagickCore::GetImageType;
   using MagickCore::GetIndexes;
@@ -673,7 +707,6 @@ namespace Magick
   using MagickCore::GetTypeMetrics;
   using MagickCore::GlobExpression;
   using MagickCore::GreaterValue;
-  using MagickCore::ConvertHSLToRGB;
   using MagickCore::HeightValue;
   using MagickCore::ImageError;
   using MagickCore::ImageFatalError;
@@ -713,36 +746,36 @@ namespace Magick
   using MagickCore::MonitorFatalError;
   using MagickCore::MonitorWarning;
   using MagickCore::MontageInfo;
+  using MagickCore::MotionBlurImage;
   using MagickCore::NegateImage;
-  using MagickCore::NewPixelWand;
   using MagickCore::NewMagickWandFromImage;
-  using MagickCore::NoValue;
+  using MagickCore::NewPixelWand;
   using MagickCore::NoiseType;
   using MagickCore::NormalizeImage;
+  using MagickCore::NoValue;
   using MagickCore::OilPaintImage;
-  using MagickCore::AcquireCacheView;
+  using MagickCore::OpaquePaintImage;
   using MagickCore::OptionError;
   using MagickCore::OptionFatalError;
   using MagickCore::OptionWarning;
-  using MagickCore::FloodfillPaintImage;
   using MagickCore::ParseMetaGeometry;
   using MagickCore::PercentValue;
-  using MagickCore::OpaquePaintImage;
-  using MagickCore::TransparentPaintImage;
   using MagickCore::PingBlob;
   using MagickCore::PingImage;
   using MagickCore::PixelSetQuantumColor;
 	using MagickCore::PixelWand;
   using MagickCore::PointInfo;
+  using MagickCore::PopDrawingWand;
   using MagickCore::ProfileImage;
   using MagickCore::ProfileInfo;
+  using MagickCore::PushDrawingWand;
   using MagickCore::QuantizeImage;
   using MagickCore::QuantizeInfo;
   using MagickCore::QuantumInfo;
   using MagickCore::QueryColorDatabase;
   using MagickCore::QueryMagickColor;
-  using MagickCore::RGBTransformImage;
   using MagickCore::RaiseImage;
+  using MagickCore::RandomChannelThresholdImage;
   using MagickCore::ReadImage;
   using MagickCore::RectangleInfo;
   using MagickCore::RectangleInfo;
@@ -758,13 +791,14 @@ namespace Magick
   using MagickCore::ResourceLimitError;
   using MagickCore::ResourceLimitFatalError;
   using MagickCore::ResourceLimitWarning;
+  using MagickCore::RGBTransformImage;
   using MagickCore::RollImage;
   using MagickCore::RotateImage;
   using MagickCore::SampleImage;
   using MagickCore::ScaleImage;
   using MagickCore::SegmentImage;
   using MagickCore::SeparateImageChannel;
-  using MagickCore::SetCacheView;
+  using MagickCore::SetCacheViewPixels;
   using MagickCore::SetClientName;
   using MagickCore::SetImageBackgroundColor;
   using MagickCore::SetImageChannelDepth;
@@ -777,14 +811,15 @@ namespace Magick
   using MagickCore::SetImagePixels;
   using MagickCore::SetImageProfile;
   using MagickCore::SetImageProperty;
+  using MagickCore::SetImageRegistry;
   using MagickCore::SetImageType;
   using MagickCore::SetLogEventMask;
   using MagickCore::SetMagickInfo;
-  using MagickCore::SetImageRegistry;
   using MagickCore::SetMagickResourceLimit;
   using MagickCore::SetStringInfoDatum;
   using MagickCore::ShadeImage;
   using MagickCore::SharpenImage;
+  using MagickCore::SharpenImageChannel;
   using MagickCore::ShaveImage;
   using MagickCore::ShearImage;
   using MagickCore::SigmoidalContrastImageChannel;
@@ -803,9 +838,9 @@ namespace Magick
   using MagickCore::SyncImagePixels;
   using MagickCore::TextureImage;
   using MagickCore::ThrowException;
-  using MagickCore::ConvertRGBToHSL;
   using MagickCore::TransformImage;
   using MagickCore::TransformRGBImage;
+  using MagickCore::TransparentPaintImage;
   using MagickCore::TrimImage;
   using MagickCore::TypeError;
   using MagickCore::TypeFatalError;
@@ -814,6 +849,7 @@ namespace Magick
   using MagickCore::UndefinedRegistryType;
   using MagickCore::UnregisterMagickInfo;
   using MagickCore::UnsharpMaskImage;
+  using MagickCore::UnsharpMaskImageChannel;
   using MagickCore::ViewInfo;
   using MagickCore::WaveImage;
   using MagickCore::WidthValue;
