@@ -67,7 +67,7 @@ namespace Magick
     void decode ( const QuantumType quantum_,
 		  const unsigned char *source_ )
       {
-	MagickLib::ReadPixelCache( _image.image(), quantum_, source_ );
+	MagickCore::ReadPixelCache( _image.image(), quantum_, source_ );
       }
     
     // Transfer one or more pixel components from the image pixel
@@ -75,7 +75,7 @@ namespace Magick
     void encode ( const QuantumType quantum_,
 		  const unsigned char *destination_ )
       {
-	MagickLib::WritePixelCache( _image.image(), quantum_, destination_ );
+	MagickCore::WritePixelCache( _image.image(), quantum_, destination_ );
       }
 #endif
   private:
@@ -85,7 +85,7 @@ namespace Magick
     const Pixels& operator=( const Pixels& pixels_ );
 
     Magick::Image          _image;   // Image reference
-    MagickLib::ViewInfo*   _view;    // Image view handle
+    MagickCore::ViewInfo*   _view;    // Image view handle
     int                    _x;       // Left ordinate of view
     int                    _y;       // Top ordinate of view
     unsigned int           _columns; // Width of view
