@@ -46,9 +46,9 @@ Magick::Options::Options( const Magick::Options& options_ )
 }
 
 // Construct using raw structures
-Magick::Options::Options( const MagickLib::ImageInfo* imageInfo_,
-                          const MagickLib::QuantizeInfo* quantizeInfo_,
-                          const MagickLib::DrawInfo* drawInfo_ )
+Magick::Options::Options( const MagickCore::ImageInfo* imageInfo_,
+                          const MagickCore::QuantizeInfo* quantizeInfo_,
+                          const MagickCore::DrawInfo* drawInfo_ )
 : _imageInfo(0),
   _quantizeInfo(0),
   _drawInfo(0)
@@ -242,14 +242,14 @@ void Magick::Options::fillColor ( const Magick::Color &fillColor_ )
 {
   _drawInfo->fill = fillColor_;
   if (fillColor_ == Magick::Color())
-    fillPattern((const MagickLib::Image*) NULL);
+    fillPattern((const MagickCore::Image*) NULL);
 }
 Magick::Color Magick::Options::fillColor ( void ) const
 {
   return _drawInfo->fill;
 }
 // Pattern image to use when filling objects
-void Magick::Options::fillPattern ( const MagickLib::Image *fillPattern_ )
+void Magick::Options::fillPattern ( const MagickCore::Image *fillPattern_ )
 {
   if ( _drawInfo->fill_pattern )
     {
@@ -261,7 +261,7 @@ void Magick::Options::fillPattern ( const MagickLib::Image *fillPattern_ )
       ExceptionInfo exceptionInfo;
       GetExceptionInfo( &exceptionInfo );
       _drawInfo->fill_pattern =
-	CloneImage( const_cast<MagickLib::Image*>(fillPattern_),
+	CloneImage( const_cast<MagickCore::Image*>(fillPattern_),
 		    0,
 		    0,
 		    static_cast<MagickBooleanType>(MagickTrue),
@@ -270,7 +270,7 @@ void Magick::Options::fillPattern ( const MagickLib::Image *fillPattern_ )
   DestroyExceptionInfo( &exceptionInfo );
     }
 }
-const MagickLib::Image* Magick::Options::fillPattern ( void  ) const
+const MagickCore::Image* Magick::Options::fillPattern ( void  ) const
 {
   return _drawInfo->fill_pattern;
 }
@@ -566,7 +566,7 @@ unsigned int Magick::Options::strokeMiterLimit ( void ) const
 }
 
 // Pattern image to use for stroked outlines
-void Magick::Options::strokePattern ( const MagickLib::Image *strokePattern_ )
+void Magick::Options::strokePattern ( const MagickCore::Image *strokePattern_ )
 {
   if ( _drawInfo->stroke_pattern )
     {
@@ -579,7 +579,7 @@ void Magick::Options::strokePattern ( const MagickLib::Image *strokePattern_ )
       ExceptionInfo exceptionInfo;
       GetExceptionInfo( &exceptionInfo );
       _drawInfo->stroke_pattern =
-	CloneImage( const_cast<MagickLib::Image*>(strokePattern_),
+	CloneImage( const_cast<MagickCore::Image*>(strokePattern_),
 		    0,
 		    0,
 		    MagickTrue,
@@ -588,7 +588,7 @@ void Magick::Options::strokePattern ( const MagickLib::Image *strokePattern_ )
   DestroyExceptionInfo( &exceptionInfo );
     }
 }
-const MagickLib::Image* Magick::Options::strokePattern ( void  ) const
+const MagickCore::Image* Magick::Options::strokePattern ( void  ) const
 {
   return _drawInfo->stroke_pattern;
 }
@@ -831,17 +831,17 @@ std::string Magick::Options::x11Display ( void ) const
 // Internal implementation methods.  Please do not use.
 //
 
-MagickLib::DrawInfo * Magick::Options::drawInfo( void )
+MagickCore::DrawInfo * Magick::Options::drawInfo( void )
 {
   return _drawInfo;
 }
 
-MagickLib::ImageInfo * Magick::Options::imageInfo( void )
+MagickCore::ImageInfo * Magick::Options::imageInfo( void )
 {
   return _imageInfo;
 }
 
-MagickLib::QuantizeInfo * Magick::Options::quantizeInfo( void )
+MagickCore::QuantizeInfo * Magick::Options::quantizeInfo( void )
 {
   return _quantizeInfo;
 }
