@@ -105,7 +105,7 @@ Magick::PixelPacket* Magick::Pixels::set ( const int x_,
   _columns = columns_;
   _rows = rows_;
 
-  PixelPacket* pixels = SetCacheView( _view, static_cast<long>(x_), static_cast<long>(y_),
+  PixelPacket* pixels = SetCacheViewPixels( _view, static_cast<long>(x_), static_cast<long>(y_),
                                       columns_, rows_ );
   if ( !pixels )
     _image.throwImageException();
