@@ -52,9 +52,9 @@ int main( int /*argc*/, char ** argv)
     colorHistogram( &histogram, image );
 
     // Print out histogram
-#if (QuantumDepth == 8)
+#if (MAGICKCORE_QUANTUM_DEPTH == 8)
     int quantum_width=3;
-#elif (QuantumDepth == 16)
+#elif (MAGICKCORE_QUANTUM_DEPTH == 16)
     int quantum_width=5;
 #else
     int quantum_width=10;
