@@ -52,6 +52,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/monitor-private.h"
 #include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
@@ -176,14 +177,8 @@ static Image *ReadARTImage(const ImageInfo *image_info,ExceptionInfo *exception)
     count=ReadBlob(image,(size_t) (-(ssize_t) length) & 0x01,pixels);
     if (SyncImagePixels(image) == MagickFalse)
       break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(LoadImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    if (SetImageProgress(image,LoadImageTag,y,image->rows) == MagickFalse)
+      break;
   }
   SetQuantumImageType(image,quantum_type);
   quantum_info=DestroyQuantumInfo(quantum_info);
@@ -345,14 +340,8 @@ static MagickBooleanType WriteARTImage(const ImageInfo *image_info,Image *image)
     if (count != (ssize_t) length)
       ThrowWriterException(CorruptImageError,"UnableToWriteImageData");
     count=WriteBlob(image,(size_t) (-(ssize_t) length) & 0x01,pixels);
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(SaveImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    if (SetImageProgress(image,SaveImageTag,y,image->rows) == MagickFalse)
+      break;
   }
   pixels=(unsigned char *) RelinquishMagickMemory(pixels);
   (void) CloseBlob(image);
