@@ -1062,7 +1062,7 @@ static Image *DecodeAVIImage(const ImageInfo *image_info,
   for (i=1; ; i++)
   {
     (void) FormatMagickString(read_info->filename,MaxTextExtent,"%08ld.png",i);
-    if (IsAccessible(read_info->filename) == MagickFalse)
+    if (IsPathAccessible(read_info->filename) == MagickFalse)
       break;
     image=ReadImage(read_info,exception);
     if (image == (Image *) NULL)
@@ -1080,7 +1080,7 @@ static Image *DecodeAVIImage(const ImageInfo *image_info,
   for (i=1; ; i++)
   {
     (void) FormatMagickString(read_info->filename,MaxTextExtent,"%08ld.png",i);
-    if (IsAccessible(read_info->filename) == MagickFalse)
+    if (IsPathAccessible(read_info->filename) == MagickFalse)
       break;
     (void) RelinquishUniqueFileResource(read_info->filename);
   }
