@@ -190,15 +190,9 @@ static Image *ReadAVSImage(const ImageInfo *image_info,ExceptionInfo *exception)
       }
       if (SyncImagePixels(image) == MagickFalse)
         break;
-      if (image->previous == (Image *) NULL)
-        if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-            (QuantumTick(y,image->rows) != MagickFalse))
-          {
-            status=image->progress_monitor(LoadImageTag,y,image->rows,
-              image->client_data);
-            if (status == MagickFalse)
-              break;
-          }
+      if ((image->previous == (Image *) NULL) &&
+          (SetImageProgress(image,LoadImageTag,y,image->rows) == MagickFalse))
+        break;
     }
     pixels=(unsigned char *) RelinquishMagickMemory(pixels);
     if (EOFBlob(image) != MagickFalse)
@@ -227,13 +221,10 @@ static Image *ReadAVSImage(const ImageInfo *image_info,ExceptionInfo *exception)
             return((Image *) NULL);
           }
         image=SyncNextImageInList(image);
-        if (image->progress_monitor != (MagickProgressMonitor) NULL)
-          {
-            status=image->progress_monitor(LoadImagesTag,TellBlob(image),
-              GetBlobSize(image),image->client_data);
-            if (status == MagickFalse)
-              break;
-          }
+        status=SetImageProgress(image,LoadImagesTag,TellBlob(image),
+          GetBlobSize(image));
+        if (status == MagickFalse)
+          break;
       }
   } while ((width != 0UL) && (height != 0UL));
   (void) CloseBlob(image);
@@ -393,28 +384,18 @@ static MagickBooleanType WriteAVSImage(const ImageInfo *image_info,Image *image)
         p++;
       }
       (void) WriteBlob(image,(size_t) (q-pixels),pixels);
-      if (image->previous == (Image *) NULL)
-        if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-            (QuantumTick(y,image->rows) != MagickFalse))
-          {
-            status=image->progress_monitor(SaveImageTag,y,image->rows,
-              image->client_data);
-            if (status == MagickFalse)
-              break;
-          }
+      if ((image->previous == (Image *) NULL) &&
+          (SetImageProgress(image,SaveImageTag,y,image->rows) == MagickFalse))
+        break;
     }
     pixels=(unsigned char *) RelinquishMagickMemory(pixels);
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
-    if (image->progress_monitor != (MagickProgressMonitor) NULL)
-      {
-        status=image->progress_monitor(SaveImagesTag,scene,
-          GetImageListLength(image),image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
-    scene++;
+    status=SetImageProgress(image,SaveImagesTag,scene++,
+      GetImageListLength(image));
+    if (status == MagickFalse)
+      break;
   } while (image_info->adjoin != MagickFalse);
   (void) CloseBlob(image);
   return(MagickTrue);
