@@ -197,9 +197,6 @@ static MagickBooleanType DecodeImage(Image *image,
   long
     y;
 
-  MagickBooleanType
-    status;
-
   register long
     i,
     x;
@@ -312,14 +309,8 @@ static MagickBooleanType DecodeImage(Image *image,
           }
         }
       }
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(LoadImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    if (SetImageProgress(image,LoadImageTag,y,image->rows) == MagickFalse)
+      break;
   }
   (void) ReadBlobByte(image);  /* end of line */
   (void) ReadBlobByte(image);
@@ -408,14 +399,9 @@ static size_t EncodeImage(Image *image,const unsigned long bytes_per_line,
     */
     *q++=(unsigned char) 0x00;
     *q++=(unsigned char) 0x00;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(SaveImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    status=SetImageProgress(image,SaveImageTag,y,image->rows);
+    if (status == MagickFalse)
+      break;
   }
   /*
     End of bitmap.
@@ -641,8 +627,8 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
         */
         if (bmp_info.size < 40)
           ThrowReaderException(CorruptImageError,"NonOS2HeaderSizeError");
-        bmp_info.width=(long) ReadBlobLSBLong(image);
-        bmp_info.height=(long) ReadBlobLSBLong(image);
+        bmp_info.width=(int) ReadBlobLSBLong(image);
+        bmp_info.height=(int) ReadBlobLSBLong(image);
         bmp_info.planes=ReadBlobLSBShort(image);
         bmp_info.bits_per_pixel=ReadBlobLSBShort(image);
         bmp_info.compression=ReadBlobLSBLong(image);
@@ -1031,14 +1017,11 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         break;
       }
@@ -1074,14 +1057,11 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         break;
       }
@@ -1112,14 +1092,11 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
             break;
           offset=(MagickOffsetType) (image->rows-y-1);
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(offset,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,offset,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         break;
       }
@@ -1180,14 +1157,11 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
             break;
           offset=(MagickOffsetType) (image->rows-y-1);
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(offset,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,offset,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         break;
       }
@@ -1214,14 +1188,11 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
             break;
           offset=(MagickOffsetType) (image->rows-y-1);
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(offset,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,offset,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         break;
       }
@@ -1275,14 +1246,11 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
             break;
           offset=(MagickOffsetType) (image->rows-y-1);
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(offset,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,offset,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         break;
       }
@@ -1339,13 +1307,10 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
             return((Image *) NULL);
           }
         image=SyncNextImageInList(image);
-        if (image->progress_monitor != (MagickProgressMonitor) NULL)
-          {
-            status=image->progress_monitor(LoadImagesTag,TellBlob(image),
-              GetBlobSize(image),image->client_data);
-            if (status == MagickFalse)
-              break;
-          }
+        status=SetImageProgress(image,LoadImagesTag,TellBlob(image),
+          GetBlobSize(image));
+        if (status == MagickFalse)
+          break;
       }
   } while (IsBMP(magick,2) != MagickFalse);
   (void) CloseBlob(image);
@@ -1547,7 +1512,7 @@ static MagickBooleanType WriteBMPImage(const ImageInfo *image_info,Image *image)
           else
             if (image->colors <= 256)
               bmp_info.bits_per_pixel=8;
-        if (image->compression == RLECompression)
+        if (image_info->compression == RLECompression)
           bmp_info.bits_per_pixel=8;
         bmp_info.number_colors=1UL << bmp_info.bits_per_pixel;
         if (image->matte != MagickFalse)
@@ -1672,22 +1637,19 @@ static MagickBooleanType WriteBMPImage(const ImageInfo *image_info,Image *image)
                 byte=0;
               }
            }
-         if (bit != 0)
-           {
-             *q++=(unsigned char) (byte << (8-bit));
-             x++;
-           }
-         for (x=(long) (image->columns+7)/8; x < (long) bytes_per_line; x++)
-           *q++=0x00;
-         if (image->previous == (Image *) NULL)
-           if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-               (QuantumTick(y,image->rows) != MagickFalse))
+           if (bit != 0)
              {
-               status=image->progress_monitor(SaveImageTag,y,image->rows,
-                 image->client_data);
-               if (status == MagickFalse)
-                 break;
+               *q++=(unsigned char) (byte << (8-bit));
+               x++;
              }
+          for (x=(long) (image->columns+7)/8; x < (long) bytes_per_line; x++)
+            *q++=0x00;
+          if (image->previous == (Image *) NULL)
+            {
+              status=SetImageProgress(image,SaveImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         break;
       }
@@ -1726,17 +1688,14 @@ static MagickBooleanType WriteBMPImage(const ImageInfo *image_info,Image *image)
              *q++=(unsigned char) (byte << 4);
              x++;
            }
-         for (x=(long) (image->columns+1)/2; x < (long) bytes_per_line; x++)
-           *q++=0x00;
-         if (image->previous == (Image *) NULL)
-           if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-               (QuantumTick(y,image->rows) != MagickFalse))
-             {
-               status=image->progress_monitor(SaveImageTag,y,image->rows,
-                 image->client_data);
-               if (status == MagickFalse)
-                 break;
-             }
+          for (x=(long) (image->columns+1)/2; x < (long) bytes_per_line; x++)
+            *q++=0x00;
+          if (image->previous == (Image *) NULL)
+            {
+              status=SetImageProgress(image,SaveImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         break;
       }
@@ -1757,14 +1716,11 @@ static MagickBooleanType WriteBMPImage(const ImageInfo *image_info,Image *image)
           for ( ; x < (long) bytes_per_line; x++)
             *q++=0x00;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(SaveImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,SaveImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         break;
       }
@@ -1793,20 +1749,17 @@ static MagickBooleanType WriteBMPImage(const ImageInfo *image_info,Image *image)
             for (x=3L*(long) image->columns; x < (long) bytes_per_line; x++)
               *q++=0x00;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(SaveImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,SaveImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         break;
       }
     }
     if ((type > 2) && (bmp_info.bits_per_pixel == 8))
-      if (image->compression != NoCompression)
+      if (image_info->compression != NoCompression)
         {
           size_t
             length;
@@ -2047,14 +2000,10 @@ static MagickBooleanType WriteBMPImage(const ImageInfo *image_info,Image *image)
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
-    if (image->progress_monitor != (MagickProgressMonitor) NULL)
-      {
-        status=image->progress_monitor(SaveImagesTag,scene,
-          GetImageListLength(image),image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
-    scene++;
+    status=SetImageProgress(image,SaveImagesTag,scene++,
+      GetImageListLength(image));
+    if (status == MagickFalse)
+      break;
   } while (image_info->adjoin != MagickFalse);
   (void) CloseBlob(image);
   return(MagickTrue);
