@@ -322,18 +322,12 @@ static MagickBooleanType WriteBRAILLEImage(const ImageInfo *image_info,
           (void) WriteBlobByte(image,iso_to_brf[cell]);
         }
     }
-
-    if (image->previous == (Image *) NULL)
-      if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-          (QuantumTick(y,image->rows) != MagickFalse))
-        {
-          status=image->progress_monitor(SaveImageTag,y,image->rows,
-            image->client_data);
-          if (status == MagickFalse)
-            break;
-        }
     if (!iso_11548_1)
       (void) WriteBlobByte(image,'\n');
+    image=SyncNextImageInList(image);
+    status=SetImageProgress(image,SaveImageTag,y,image->rows);
+    if (status == MagickFalse)
+      break;
   }
   (void) CloseBlob(image);
   return(MagickTrue);
