@@ -695,6 +695,11 @@ static Image *ReadCINImage(const ImageInfo *image_info,
       (void) CloseBlob(image);
       return(image);
     }
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   /*
     Convert CIN raster image to pixel packets.
   */
@@ -702,19 +707,14 @@ static Image *ReadCINImage(const ImageInfo *image_info,
   quantum_info->quantum=32;
   quantum_info->pack=MagickFalse;
   quantum_type=RGBQuantum;
+  pixels=GetQuantumPixels(quantum_info);
+  length=GetQuantumExtent(image,quantum_info,quantum_type);
   length=GetBytesPerRow(image->columns,3,image->depth,MagickTrue);
   if (cin.image.number_channels == 1)
     {
       quantum_type=GrayQuantum;
       length=GetBytesPerRow(image->columns,1,image->depth,MagickTrue);
     }
-  if (SetImageExtent(image,0,0) == MagickFalse)
-    {
-      InheritException(exception,&image->exception);
-      return(DestroyImageList(image));
-    }
-  pixels=GetQuantumPixels(quantum_info);
-  length=GetQuantumExtent(image,quantum_info,quantum_type);
   for (y=0; y < (long) image->rows; y++)
   {
     q=SetImagePixels(image,0,y,image->columns,1);
@@ -727,14 +727,11 @@ static Image *ReadCINImage(const ImageInfo *image_info,
     if (SyncImagePixels(image) == MagickFalse)
       break;
     if (image->previous == (Image *) NULL)
-      if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-          (QuantumTick(y,image->rows) != MagickFalse))
-        {
-          status=image->progress_monitor(LoadImageTag,y,image->rows,
-            image->client_data);
-          if (status == MagickFalse)
-            break;
-        }
+      {
+        status=SetImageProgress(image,LoadImageTag,y,image->rows);
+        if (status == MagickFalse)
+          break;
+      }
   }
   SetQuantumImageType(image,quantum_type);
   quantum_info=DestroyQuantumInfo(quantum_info);
@@ -1161,6 +1158,9 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
     count=WriteBlob(image,length,pixels);
     if (count != (ssize_t) length)
       break;
+    status=SetImageProgress(image,SaveImageTag,y,image->rows);
+    if (status == MagickFalse)
+      break;
   }
   quantum_info=DestroyQuantumInfo(quantum_info);
   (void) CloseBlob(image);
