@@ -255,14 +255,9 @@ static MagickBooleanType WriteCIPImage(const ImageInfo *image_info,Image *image)
         (void) FormatMagickString(buffer,MaxTextExtent,"%02x",~byte);
         (void) WriteBlobString(image,buffer);
       }
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(SaveImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    status=SetImageProgress(image,SaveImageTag,y,image->rows);
+    if (status == MagickFalse)
+      break;
   }
   (void) WriteBlobString(image,"</Data>\n");
   (void) WriteBlobString(image,"</CiscoIPPhoneImage>\n");
