@@ -192,7 +192,7 @@ static Image *ReadCLIPBOARDImage(const ImageInfo *image_info,
         }
       if (hPal != NULL)
       {
-        /* Kenichi Masuko says this is needed */
+        /* Kenichi Masuko says this needed */
         SelectPalette(hDC, hPal, FALSE);
         RealizePalette(hDC);
       }
@@ -260,6 +260,7 @@ ModuleExport unsigned long RegisterCLIPBOARDImage(void)
   entry->encoder=(EncodeImageHandler *) WriteCLIPBOARDImage;
 #endif
   entry->adjoin=MagickFalse;
+  entry->format_type=ImplicitFormatType;
   entry->description=ConstantString("The system clipboard");
   entry->module=ConstantString("CLIPBOARD");
   (void) RegisterMagickInfo(entry);
