@@ -257,14 +257,11 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
                 break;
             }
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         break;
       }
@@ -332,14 +329,11 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
               }
           }
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         break;
       }
@@ -401,10 +395,9 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
                 break;
             }
         }
-        if (image->progress_monitor != (MagickProgressMonitor) NULL)
+        if (image->previous == (Image *) NULL)
           {
-            status=image->progress_monitor(LoadImageTag,100,500,
-              image->client_data);
+            status=SetImageProgress(image,LoadImageTag,1,5);
             if (status == MagickFalse)
               break;
           }
@@ -453,10 +446,9 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
                 break;
             }
         }
-        if (image->progress_monitor != (MagickProgressMonitor) NULL)
+        if (image->previous == (Image *) NULL)
           {
-            status=image->progress_monitor(LoadImageTag,200,500,
-              image->client_data);
+            status=SetImageProgress(image,LoadImageTag,2,5);
             if (status == MagickFalse)
               break;
           }
@@ -505,10 +497,9 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
                 break;
             }
         }
-        if (image->progress_monitor != (MagickProgressMonitor) NULL)
+        if (image->previous == (Image *) NULL)
           {
-            status=image->progress_monitor(LoadImageTag,200,500,
-              image->client_data);
+            status=SetImageProgress(image,LoadImageTag,3,5);
             if (status == MagickFalse)
               break;
           }
@@ -559,15 +550,14 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
                 break;
             }
         }
+        if (image->previous == (Image *) NULL)
+          {
+            status=SetImageProgress(image,LoadImageTag,4,5);
+            if (status == MagickFalse)
+              break;
+          }
         if (image->matte != MagickFalse)
           {
-            if (image->progress_monitor != (MagickProgressMonitor) NULL)
-              {
-                status=image->progress_monitor(LoadImageTag,300,500,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
             if (image_info->interlace == PartitionInterlace)
               {
                 (void) CloseBlob(image);
@@ -615,10 +605,9 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
                 }
             }
           }
-        if (image->progress_monitor != (MagickProgressMonitor) NULL)
+        if (image->previous == (Image *) NULL)
           {
-            status=image->progress_monitor(LoadImageTag,500,500,
-              image->client_data);
+            status=SetImageProgress(image,LoadImageTag,5,5);
             if (status == MagickFalse)
               break;
           }
@@ -644,13 +633,10 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
             return((Image *) NULL);
           }
         image=SyncNextImageInList(image);
-        if (image->progress_monitor != (MagickProgressMonitor) NULL)
-          {
-            status=image->progress_monitor(LoadImagesTag,TellBlob(image),
-              GetBlobSize(image),image->client_data);
-            if (status == MagickFalse)
-              break;
-          }
+        status=SetImageProgress(image,LoadImagesTag,TellBlob(image),
+          GetBlobSize(image));
+        if (status == MagickFalse)
+          break;
       }
   } while (count == (ssize_t) length);
   quantum_info=DestroyQuantumInfo(quantum_info);
@@ -845,14 +831,11 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
           if (count != (ssize_t) length)
             break;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(SaveImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,SaveImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         break;
       }
@@ -890,11 +873,9 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
               if (count != (ssize_t) length)
                 break;
             }
-          if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-              (QuantumTick(y,image->rows) != MagickFalse))
+          if (image->previous == (Image *) NULL)
             {
-              status=image->progress_monitor(SaveImageTag,y,image->rows,
-                image->client_data);
+              status=SetImageProgress(image,SaveImageTag,y,image->rows);
               if (status == MagickFalse)
                 break;
             }
@@ -925,10 +906,9 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
           if (count != (ssize_t) length)
             break;
         }
-        if (image->progress_monitor != (MagickProgressMonitor) NULL)
+        if (image->previous == (Image *) NULL)
           {
-            status=image->progress_monitor(LoadImageTag,100,500,
-              image->client_data);
+            status=SetImageProgress(image,SaveImageTag,1,5);
             if (status == MagickFalse)
               break;
           }
@@ -951,10 +931,9 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
           if (count != (ssize_t) length)
             break;
         }
-        if (image->progress_monitor != (MagickProgressMonitor) NULL)
+        if (image->previous == (Image *) NULL)
           {
-            status=image->progress_monitor(LoadImageTag,200,500,
-              image->client_data);
+            status=SetImageProgress(image,SaveImageTag,2,5);
             if (status == MagickFalse)
               break;
           }
@@ -996,15 +975,14 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
           if (count != (ssize_t) length)
             break;
         }
+        if (image->previous == (Image *) NULL)
+          {
+            status=SetImageProgress(image,SaveImageTag,3,5);
+            if (status == MagickFalse)
+              break;
+          }
         if (quantum_type == CMYKAQuantum)
           {
-            if (image->progress_monitor != (MagickProgressMonitor) NULL)
-              {
-                status=image->progress_monitor(LoadImageTag,300,500,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
             if (image_info->interlace == PartitionInterlace)
               {
                 (void) CloseBlob(image);
@@ -1026,14 +1004,19 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
               if (count != (ssize_t) length)
               break;
             }
+            if (image->previous == (Image *) NULL)
+              {
+                status=SetImageProgress(image,SaveImageTag,4,5);
+                if (status == MagickFalse)
+                  break;
+              }
           }
         if (image_info->interlace == PartitionInterlace)
           (void) CopyMagickString(image->filename,image_info->filename,
             MaxTextExtent);
-        if (image->progress_monitor != (MagickProgressMonitor) NULL)
+        if (image->previous == (Image *) NULL)
           {
-            status=image->progress_monitor(LoadImageTag,500,500,
-              image->client_data);
+            status=SetImageProgress(image,SaveImageTag,5,5);
             if (status == MagickFalse)
               break;
           }
@@ -1044,13 +1027,10 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
-    if (image->progress_monitor != (MagickProgressMonitor) NULL)
-      {
-        status=image->progress_monitor(SaveImagesTag,scene,
-          GetImageListLength(image),image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    status=SetImageProgress(image,SaveImagesTag,scene++,
+      GetImageListLength(image));
+    if (status == MagickFalse)
+      break;
     scene++;
   } while (image_info->adjoin != MagickFalse);
   (void) CloseBlob(image);
