@@ -305,8 +305,6 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
   Image *image,*palette;
   ImageInfo *clone_info;
-  MagickBooleanType
-    proceed;
   MagickBooleanType status;
 
   MagickOffsetType
@@ -416,14 +414,14 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
   (void) CopyMagickString(clone_info->filename+i,".PAL",(size_t)
     (MaxTextExtent-i));
-  if((clone_info->file=MagickOpenStream(clone_info->filename,"rb"))==NULL)
+  if((clone_info->file=OpenMagickStream(clone_info->filename,"rb"))==NULL)
     {
       (void) CopyMagickString(clone_info->filename+i,".pal",(size_t)
         (MaxTextExtent-i));
-      if((clone_info->file=MagickOpenStream(clone_info->filename,"rb"))==NULL)
+      if((clone_info->file=OpenMagickStream(clone_info->filename,"rb"))==NULL)
         {
           clone_info->filename[i]='\0';
-          if((clone_info->file=MagickOpenStream(clone_info->filename,"rb"))==NULL)
+          if((clone_info->file=OpenMagickStream(clone_info->filename,"rb"))==NULL)
             {
               clone_info=DestroyImageInfo(clone_info);
               clone_info=NULL;
