@@ -161,9 +161,6 @@ static MagickBooleanType DecodeImage(Image *image,
   long
     y;
 
-  MagickBooleanType
-    status;
-
   register long
     i,
     x;
@@ -276,14 +273,8 @@ static MagickBooleanType DecodeImage(Image *image,
           }
         }
       }
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(LoadImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    if (SetImageProgress(image,LoadImageTag,y,image->rows) == MagickFalse)
+      break;
   }
   (void) ReadBlobByte(image);  /* end of line */
   (void) ReadBlobByte(image);
@@ -328,9 +319,6 @@ static size_t EncodeImage(Image *image,const unsigned long bytes_per_line,
   long
     y;
 
-  MagickBooleanType
-    status;
-
   register const unsigned char
     *p;
 
@@ -372,14 +360,8 @@ static size_t EncodeImage(Image *image,const unsigned long bytes_per_line,
     */
     *q++=0x00;
     *q++=0x00;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(LoadImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    if (SetImageProgress(image,LoadImageTag,y,image->rows) == MagickFalse)
+      break;
   }
   /*
     End of bitmap.
@@ -694,14 +676,12 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (SyncImagePixels(image) == MagickFalse)
           break;
         if (image->previous == (Image *) NULL)
-          if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-              (QuantumTick(1L*image->rows-y-1,image->rows) != MagickFalse))
-            {
-              status=image->progress_monitor(LoadImageTag,1L*image->rows-y-1,
-                image->rows,image->client_data);
-              if (status == MagickFalse)
-                break;
-            }
+          {
+            status=SetImageProgress(image,LoadImageTag,image->rows-y-1,
+              image->rows);
+            if (status == MagickFalse)
+              break;
+          }
       }
       break;
     }
@@ -737,14 +717,12 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (SyncImagePixels(image) == MagickFalse)
           break;
         if (image->previous == (Image *) NULL)
-          if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-              (QuantumTick(1L*image->rows-y-1,image->rows) != MagickFalse))
-            {
-              status=image->progress_monitor(LoadImageTag,1L*image->rows-y-1,
-                image->rows,image->client_data);
-              if (status == MagickFalse)
-                break;
-            }
+          {
+            status=SetImageProgress(image,LoadImageTag,image->rows-y-1,
+              image->rows);
+            if (status == MagickFalse)
+              break;
+          }
       }
       break;
     }
@@ -774,14 +752,12 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (SyncImagePixels(image) == MagickFalse)
           break;
         if (image->previous == (Image *) NULL)
-          if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-              (QuantumTick(1L*image->rows-y-1,image->rows) != MagickFalse))
-            {
-              status=image->progress_monitor(LoadImageTag,1L*image->rows-y-1,
-                image->rows,image->client_data);
-              if (status == MagickFalse)
-                break;
-            }
+          {
+            status=SetImageProgress(image,LoadImageTag,image->rows-y-1,
+              image->rows);
+            if (status == MagickFalse)
+              break;
+          }
       }
       break;
     }
@@ -829,14 +805,12 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (SyncImagePixels(image) == MagickFalse)
           break;
         if (image->previous == (Image *) NULL)
-          if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-              (QuantumTick(1L*image->rows-y-1,image->rows) != MagickFalse))
-            {
-              status=image->progress_monitor(LoadImageTag,1L*image->rows-y-1,
-                image->rows,image->client_data);
-              if (status == MagickFalse)
-                break;
-            }
+          {
+            status=SetImageProgress(image,LoadImageTag,image->rows-y-1,
+              image->rows);
+            if (status == MagickFalse)
+              break;
+          }
       }
       break;
     }
@@ -864,14 +838,12 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (SyncImagePixels(image) == MagickFalse)
           break;
         if (image->previous == (Image *) NULL)
-          if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-              (QuantumTick(1L*image->rows-y-1,image->rows) != MagickFalse))
-            {
-              status=image->progress_monitor(LoadImageTag,1L*image->rows-y-1,
-                image->rows,image->client_data);
-              if (status == MagickFalse)
-                break;
-            }
+          {
+            status=SetImageProgress(image,LoadImageTag,image->rows-y-1,
+              image->rows);
+            if (status == MagickFalse)
+              break;
+          }
       }
       break;
     }
@@ -1130,22 +1102,16 @@ static MagickBooleanType WriteDIBImage(const ImageInfo *image_info,Image *image)
             }
            p++;
          }
-       if (bit != 0)
-         {
-           *q++=(unsigned char) (byte << (8-bit));
-           x++;
-         }
-       for (x=(long) (image->columns+7)/8; x < (long) bytes_per_line; x++)
-         *q++=0x00;
-       if (image->previous == (Image *) NULL)
-          if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-              (QuantumTick(y,image->rows) != MagickFalse))
-            {
-              status=image->progress_monitor(SaveImageTag,y,image->rows,
-                image->client_data);
-              if (status == MagickFalse)
-                break;
-            }
+         if (bit != 0)
+           {
+             *q++=(unsigned char) (byte << (8-bit));
+             x++;
+           }
+        for (x=(long) (image->columns+7)/8; x < (long) bytes_per_line; x++)
+          *q++=0x00;
+        status=SetImageProgress(image,SaveImageTag,y,image->rows);
+        if (status == MagickFalse)
+          break;
       }
       break;
     }
@@ -1165,15 +1131,9 @@ static MagickBooleanType WriteDIBImage(const ImageInfo *image_info,Image *image)
           *q++=(unsigned char) indexes[x];
         for ( ; x < (long) bytes_per_line; x++)
           *q++=0x00;
-        if (image->previous == (Image *) NULL)
-          if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-              (QuantumTick(y,image->rows) != MagickFalse))
-            {
-              status=image->progress_monitor(SaveImageTag,y,image->rows,
-                image->client_data);
-              if (status == MagickFalse)
-                break;
-            }
+        status=SetImageProgress(image,SaveImageTag,y,image->rows);
+        if (status == MagickFalse)
+          break;
       }
       break;
     }
@@ -1202,15 +1162,9 @@ static MagickBooleanType WriteDIBImage(const ImageInfo *image_info,Image *image)
         }
         for (x=2L*image->columns; x < (long) bytes_per_line; x++)
           *q++=0x00;
-        if (image->previous == (Image *) NULL)
-          if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-              (QuantumTick(y,image->rows) != MagickFalse))
-            {
-              status=image->progress_monitor(SaveImageTag,y,image->rows,
-                image->client_data);
-              if (status == MagickFalse)
-                break;
-            }
+        status=SetImageProgress(image,SaveImageTag,y,image->rows);
+        if (status == MagickFalse)
+          break;
       }
       break;
     }
@@ -1238,21 +1192,15 @@ static MagickBooleanType WriteDIBImage(const ImageInfo *image_info,Image *image)
         if (dib_info.bits_per_pixel == 24)
           for (x=3L*image->columns; x < (long) bytes_per_line; x++)
             *q++=0x00;
-        if (image->previous == (Image *) NULL)
-          if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-              (QuantumTick(y,image->rows) != MagickFalse))
-            {
-              status=image->progress_monitor(SaveImageTag,y,image->rows,
-                image->client_data);
-              if (status == MagickFalse)
-                break;
-            }
+        status=SetImageProgress(image,SaveImageTag,y,image->rows);
+        if (status == MagickFalse)
+          break;
       }
       break;
     }
   }
   if (dib_info.bits_per_pixel == 8)
-    if (image->compression != NoCompression)
+    if (image_info->compression != NoCompression)
       {
         size_t
           length;
